@@ -134,6 +134,8 @@ typedef struct
 
     GtkWidget         *ebox;
     GtkWidget         *box;
+    GtkWidget         *ebox_bars;
+    GtkWidget         *box_bars;
     GtkWidget         *tooltip_text;
     guint             timeout_id;
     t_monitor         *monitor;
@@ -238,11 +240,11 @@ static gboolean update_monitors(t_global_monitor *global)
         if (global->monitor->options.show_bars)
             gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(global->monitor->status[i]), temp);
 
-        format_byte_humanreadable( buffer[i], BUFSIZ, display[i], 2 );
-        format_byte_humanreadable( buffer_panel[i], BUFSIZ, display[i], 0 );
+        format_byte_humanreadable( buffer[i], BUFSIZ - 1, display[i], 2 );
+        format_byte_humanreadable( buffer_panel[i], BUFSIZ - 1, display[i], 2 );
     }
     
-    format_byte_humanreadable( buffer[TOT], BUFSIZ, (display[IN]+display[OUT]), 2 );
+    format_byte_humanreadable( buffer[TOT], BUFSIZ - 1, (display[IN]+display[OUT]), 2 );
     
     {
         char* ip = get_ip_address(&(global->monitor->data));
@@ -336,6 +338,7 @@ static void monitor_set_mode (XfcePanelPlugin *plugin, XfcePanelPluginMode mode,
     if (mode == XFCE_PANEL_PLUGIN_MODE_DESKBAR)
     {
         xfce_hvbox_set_orientation(XFCE_HVBOX(global->box), GTK_ORIENTATION_VERTICAL);
+        xfce_hvbox_set_orientation(XFCE_HVBOX(global->box_bars), GTK_ORIENTATION_VERTICAL);
         gtk_label_set_angle(GTK_LABEL(global->monitor->label), 0);
         gtk_misc_set_alignment(GTK_MISC(global->monitor->rcv_label), 0.5f, 1.0f);
         gtk_misc_set_alignment(GTK_MISC(global->monitor->sent_label), 0.5f, 0.0f);
@@ -348,6 +351,7 @@ static void monitor_set_mode (XfcePanelPlugin *plugin, XfcePanelPluginMode mode,
     else if (mode == XFCE_PANEL_PLUGIN_MODE_VERTICAL)
     {
         xfce_hvbox_set_orientation(XFCE_HVBOX(global->box), GTK_ORIENTATION_VERTICAL);
+        xfce_hvbox_set_orientation(XFCE_HVBOX(global->box_bars), GTK_ORIENTATION_VERTICAL);
         gtk_label_set_angle(GTK_LABEL(global->monitor->label), 270);
         gtk_misc_set_alignment(GTK_MISC(global->monitor->rcv_label), 0.5f, 1.0f);
         gtk_misc_set_alignment(GTK_MISC(global->monitor->sent_label), 0.5f, 0.0f);
@@ -362,6 +366,7 @@ static void monitor_set_mode (XfcePanelPlugin *plugin, XfcePanelPluginMode mode,
     else /* mode == XFCE_PANEL_PLUGIN_MODE_HORIZONTAL */
     {
         xfce_hvbox_set_orientation(XFCE_HVBOX(global->box), GTK_ORIENTATION_HORIZONTAL);
+        xfce_hvbox_set_orientation(XFCE_HVBOX(global->box_bars), GTK_ORIENTATION_HORIZONTAL);
         gtk_label_set_angle(GTK_LABEL(global->monitor->label), 0);
         gtk_misc_set_alignment(GTK_MISC(global->monitor->rcv_label), 1.0f, 0.5f);
         gtk_misc_set_alignment(GTK_MISC(global->monitor->sent_label), 0.0f, 0.5f);
@@ -471,12 +476,21 @@ static t_global_monitor * monitor_new(XfcePanelPlugin *plugin)
                        TRUE, FALSE, 2);
 
     /* Create the progress bars */
+    global->ebox_bars = gtk_event_box_new();
+    gtk_event_box_set_visible_window(GTK_EVENT_BOX(global->ebox_bars), FALSE);
+    gtk_event_box_set_above_child(GTK_EVENT_BOX(global->ebox_bars), TRUE);
+    gtk_widget_show(global->ebox_bars);
+    global->box_bars = xfce_hvbox_new(GTK_ORIENTATION_HORIZONTAL, FALSE, 0);
+    gtk_widget_show(global->box_bars);
     for (i = 0; i < SUM; i++)
     {
         global->monitor->status[i] = GTK_WIDGET(gtk_progress_bar_new());
-        gtk_box_pack_start(GTK_BOX(global->box),
+        gtk_box_pack_start(GTK_BOX(global->box_bars),
                            GTK_WIDGET(global->monitor->status[i]), FALSE, FALSE, 0);
+        gtk_widget_show(global->monitor->status[i]);
     }
+    gtk_container_add(GTK_CONTAINER(global->ebox_bars), GTK_WIDGET(global->box_bars));
+    gtk_container_add(GTK_CONTAINER(global->box), GTK_WIDGET(global->ebox_bars));
 
     /* Append sent label after the progress bars */
     gtk_box_pack_start(GTK_BOX(global->box),
@@ -532,16 +546,16 @@ static void setup_monitor(t_global_monitor *global, gboolean supress_warnings)
     }
 
     /* Setup the progress bars */
-    for (i = 0; i < SUM; i++)
+    if (global->monitor->options.show_bars)
     {
-        if (global->monitor->options.show_bars)
+        gtk_widget_show(global->ebox_bars);
+        for (i = 0; i < SUM; i++)
         {
             /* Automatic or fixed maximum */
             if (global->monitor->options.auto_max)
                 global->monitor->net_max[i] = INIT_MAX;
             else
                 global->monitor->net_max[i] = global->monitor->options.max[i];
-            gtk_widget_show(global->monitor->status[i]);
 
             /* Set bar colors */
             gtk_widget_modify_bg(GTK_WIDGET(global->monitor->status[i]),
@@ -554,10 +568,10 @@ static void setup_monitor(t_global_monitor *global, gboolean supress_warnings)
                                    GTK_STATE_SELECTED,
                                    &global->monitor->options.color[i]);
         }
-        else
-        {
-            gtk_widget_hide(global->monitor->status[i]);
-        }
+    }
+    else
+    {
+        gtk_widget_hide(global->ebox_bars);
     }
 
     if (!init_netload( &(global->monitor->data), global->monitor->options.network_device)
@@ -992,8 +1006,6 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
     gtk_size_group_add_widget(sg, global->monitor->opt_use_label);
 
     global->monitor->opt_entry = gtk_entry_new();
-    gtk_entry_set_max_length(GTK_ENTRY(global->monitor->opt_entry),
-                             MAX_LENGTH);
     gtk_entry_set_text(GTK_ENTRY(global->monitor->opt_entry),
                        global->monitor->options.label_text);
     gtk_widget_show(global->monitor->opt_entry);
@@ -1024,8 +1036,6 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
     global->monitor->net_entry = gtk_entry_new();
     gtk_label_set_mnemonic_widget(GTK_LABEL(device_label),
                                   global->monitor->net_entry);
-    gtk_entry_set_max_length(GTK_ENTRY(global->monitor->net_entry),
-                             MAX_LENGTH);
     gtk_entry_set_text(GTK_ENTRY(global->monitor->net_entry),
                        global->monitor->options.network_device);
     gtk_widget_show(global->monitor->opt_entry);
@@ -1186,8 +1196,8 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
                 FALSE, FALSE, 0);
 
         gtk_size_group_add_widget(sg, color_label[i]);
-
     }
+
     global->monitor->opt_colorize_values =
         gtk_check_button_new_with_mnemonic(_("_Colorize values"));
     gtk_widget_show(global->monitor->opt_colorize_values);
@@ -1261,4 +1271,4 @@ static void netload_construct (XfcePanelPlugin *plugin)
     run_update( global );
 }
 
-XFCE_PANEL_PLUGIN_REGISTER_EXTERNAL (netload_construct);
+XFCE_PANEL_PLUGIN_REGISTER (netload_construct);
